@@ -1,29 +1,18 @@
 //  -*- c-basic-offset:4; indent-tabs-mode:nil -*-
-/* This file is part of the KDE libraries
-   Copyright (C) 2002-2003  Alexander Kellett <lypanov@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002-2003 Alexander Kellett <lypanov@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kbookmarkimporter_ie.h"
 
 #include <QFileDialog>
 
-#include <QtCore/QDebug>
-#include <qtextcodec.h>
+#include "kbookmarks_debug.h"
 #include <QApplication>
+#include <QRegularExpression>
 
 #include <qplatformdefs.h>
 
@@ -70,13 +59,14 @@ void KIEBookmarkImporter::parseIEBookmarks_url_file(const QString &filename, con
 
         while (f.readLine(s.data(), g_lineLimit) >= 0) {
             if (s[s.length() - 1] != '\n') { // Gosh, this line is longer than g_lineLimit. Skipping.
-                qWarning() << "IE bookmarks contain a line longer than " << g_lineLimit << ". Skipping.";
+                qCWarning(KBOOKMARKS_LOG) << "IE bookmarks contain a line longer than " << g_lineLimit << ". Skipping.";
                 continue;
             }
-            QByteArray t = s.trimmed();
-            QRegExp rx("URL=(.*)");
-            if (rx.exactMatch(t)) {
-                emit newBookmark(name, rx.cap(1), QString(""));
+            const QString t = QString::fromUtf8(s.trimmed());
+            QRegularExpression rx(QStringLiteral("URL=(.*)"));
+            auto match = rx.match(t);
+            if (match.hasMatch()) {
+                emit newBookmark(name, match.captured(1), QLatin1String(""));
             }
         }
 
@@ -90,7 +80,7 @@ void KIEBookmarkImporter::parseIEBookmarks_dir(const QString &dirname, const QSt
     QDir dir(dirname);
     dir.setFilter(QDir::Files | QDir::Dirs | QDir::AllDirs);
     dir.setSorting(QFlags<QDir::SortFlag>(QDir::Name | QDir::DirsFirst));
-    dir.setNameFilters(QStringList("*.url")); // AK - possibly add ";index.ini" ?
+    dir.setNameFilters(QStringList(QStringLiteral("*.url"))); // AK - possibly add ";index.ini" ?
 
     const QFileInfoList list = dir.entryInfoList();
     if (list.isEmpty()) {
@@ -98,11 +88,11 @@ void KIEBookmarkImporter::parseIEBookmarks_dir(const QString &dirname, const QSt
     }
 
     if (dirname != m_fileName) {
-        emit newFolder(foldername, false, "");
+        emit newFolder(foldername, false, QLatin1String(""));
     }
 
-    foreach (const QFileInfo &fi, list) {
-        if (fi.fileName() == "." || fi.fileName() == "..") {
+    for (const QFileInfo &fi : list) {
+        if (fi.fileName() == QLatin1String(".") || fi.fileName() == QLatin1String("..")) {
             continue;
         }
 
@@ -131,7 +121,7 @@ void KIEBookmarkImporter::parseIEBookmarks()
 
 QString KIEBookmarkImporter::IEBookmarksDir()
 {
-    static KIEBookmarkImporterImpl *p = 0;
+    static KIEBookmarkImporterImpl *p = nullptr;
     if (!p) {
         p = new KIEBookmarkImporterImpl;
     }
@@ -167,9 +157,9 @@ public:
         traverse(grp);
     }
 private:
-    void visit(const KBookmark &) Q_DECL_OVERRIDE;
-    void visitEnter(const KBookmarkGroup &) Q_DECL_OVERRIDE;
-    void visitLeave(const KBookmarkGroup &) Q_DECL_OVERRIDE;
+    void visit(const KBookmark &) override;
+    void visitEnter(const KBookmarkGroup &) override;
+    void visitLeave(const KBookmarkGroup &) override;
 private:
     QDir m_currentDir;
 };
@@ -177,7 +167,7 @@ private:
 static QString ieStyleQuote(const QString &str)
 {
     QString s(str);
-    s.replace(QRegExp("[/\\:*?\"<>|]"), "_");
+    s.replace(QRegularExpression(QStringLiteral("[/\\:*?\"<>|]")), QStringLiteral("_"));
     return s;
 }
 
@@ -188,8 +178,8 @@ IEExporter::IEExporter(const QString &dname)
 
 void IEExporter::visit(const KBookmark &bk)
 {
-    QString fname = m_currentDir.path() + '/' + ieStyleQuote(bk.fullText()) + ".url";
-    // qDebug() << "visit(" << bk.text() << "), fname == " << fname;
+    const QString fname = m_currentDir.path() + QLatin1Char('/') + ieStyleQuote(bk.fullText()) + QLatin1String(".url");
+    // qCDebug(KBOOKMARKS_LOG) << "visit(" << bk.text() << "), fname == " << fname;
     QFile file(fname);
     if (file.open(QIODevice::WriteOnly)) {
         QTextStream ts(&file);
@@ -200,15 +190,15 @@ void IEExporter::visit(const KBookmark &bk)
 
 void IEExporter::visitEnter(const KBookmarkGroup &grp)
 {
-    QString dname = m_currentDir.path() + '/' + ieStyleQuote(grp.fullText());
-    // qDebug() << "visitEnter(" << grp.text() << "), dname == " << dname;
+    const QString dname = m_currentDir.path() + QLatin1Char('/') + ieStyleQuote(grp.fullText());
+    // qCDebug(KBOOKMARKS_LOG) << "visitEnter(" << grp.text() << "), dname == " << dname;
     m_currentDir.mkdir(dname);
     m_currentDir.cd(dname);
 }
 
 void IEExporter::visitLeave(const KBookmarkGroup &)
 {
-    // qDebug() << "visitLeave()";
+    // qCDebug(KBOOKMARKS_LOG) << "visitLeave()";
     m_currentDir.cdUp();
 }
 
